class Camera:
    """
        This class can control the position, size, and direction of AnimationSprite-inherited classes.
        To run the example program, enter the command in cmd:
            run-Animation-example-camera
        to run the example program.
        

        这个类可以控制以 AnimationSprite 继承的类的位置、大小、方向。
        在 cmd 中输入命令：
            run-Animation-example-camera
        即可运行示例程序。
    """
    def __init__(self) -> None: ...

    @staticmethod
    def set_screen_center(x : int, y : int) -> None:
        """
        Sets the center point of the window.
        If your window name is "screen", you can use:
            set_screen_center(screen.get_width()/2, screen.get_height()/2)
        to set the center point of the window.

        
        设置窗口的中心点坐标。
        如果你的窗口名字是 screen ，那么就可以：
            set_screen_center(screen.get_width()/2, screen.get_height()/2)
        来设置窗口的中心点坐标。
        """
        ...

    @staticmethod
    def get_screen_center(string : str = "x") -> dict[str, int]:
        """
        Gets the center point of the window.
        Enter "x" to return the x-coordinate of the center point of the window.(You can also leave it blank, because the default value is "x")
        Enter "y" to return the y-coordinate of the center point of the window.


        获取窗口中心点，输入“x”放回窗口中心坐标的x（也可以不输入，因为默认值就是x）
        输入“y”放回窗口中心坐标的y。
        """
        ...

    @staticmethod
    def set_minimum(minimum : float) -> None:
        """
        Sets the minimum camera zoom.
        The default value is 0.00000000000001, which is 1e-16.
        The smaller the value, the smaller the camera zoom.
        But do not set it too small, because it is the best value, and if it is not necessary, do not touch it.

        
        设置最小相机缩放。
        默认是 0.00000000000001，也就是 1e-16。
        这个值越小，相机的缩放就越小。
        但不要小过这个值，这个值是最佳的，如果不是必须，请别碰它。
        """
        ...

    def set_return_change(self, value : bool) -> None:
        """
        Sets whether to return the current value.
        Only functions starting with Camera are allowed.
        If it is True, it will return the current value, and if it is False, it will not print (print).

        
        设置是否返回当前的值，仅限以 Camera 开头的函数。
        是返回，不是打印(print)。
        """
        ...

    def move(self, x : int, y : int) -> None:
        """
        Moves the camera.


        移动摄像机。
        """
        ...

    def set_position(self, x : int, y : int) -> None:
        """
        Sets the camera's position.

        
        设置摄像机的坐标
        """
        ...

    def get_position(self) -> dict[int, int]:
        """
        Gets the camera's position.


        获取摄像机的坐标。
        """
        ...

    def add_size(self, size : int) -> None:
        """
        Increases the distance between the camera and the ground.


        增加摄像机与地面的距离。
        """
        ...

    def set_size(self, size : int) -> None:
        """
        Sets the distance between the camera and the ground.


        设置摄像机与地面的距离。
        """
        ...

    def get_size(self) -> int:
        """
        Gets the distance between the camera and the ground.


        获取摄像机与地面的距离
        """
        ...

    def turn_left(self, angle : int) -> None:
        """
        Turns the camera to the left.
        

        向左转摄像机
        """
        ...

    def turn_right(self, angle : int) -> None:
        """
        Turns the camera to the right.
        
        
        向右转摄像机
        """
        ...

    def set_direction(self, angle : int) -> None:
        """
        Sets the direction of the camera.
        

        设置摄像机的方向。
        """
        ...

    def get_direction(self) -> int:
        """
        Gets the direction of the camera.


        获取摄像机的方向
        """
        ...