class RGB:
    """
    RGB type

    RGB type represents color, which contains three values: red, green, and blue.

    RGB type provides the following methods:

    - __init__(r : int = 0, g : int = 0, b : int = 0) -> None: Constructor, used to initialize RGB values.
    - __str__() -> str: Used to return the string representation of RGB values.
    - of() -> tuple: Used to return the tuple representation of RGB values.
    - ofnum(r : int, g : int, b : int) -> 'RGB': Used to return RGB values.
    - ofhex(hex_str : str) -> RGB: Used to return RGB values.

    RGB type provides the following attributes:

    - r: Red value.
    - g: Green value.
    - b: Blue value.




    RGB 类型

    RGB 类型用于表示颜色，包含三个值：红色、绿色、蓝色。

    RGB 类型提供了以下方法：

    - __init__(r : int = 0, g : int = 0, b : int = 0) -> None: 构造函数，用于初始化 RGB 值。
    - __str__() -> str: 用于返回 RGB 值的字符串表示。
    - of() -> tuple: 用于返回 RGB 值的元组表示。
    - ofnum(r : int, g : int, b : int) -> 'RGB': 用于返回 RGB 值。
    - ofhex(hex_str : str) -> RGB: 用于返回 RGB 值。

    RGB 类型提供了以下属性：

    - r: 红色值。
    - g: 绿色值。
    - b: 蓝色值。

    """
    def __init__(self, r : int = 0, g : int = 0, b : int = 0) -> None: ...
    def __str__(self) -> str:...
    def of(self) -> tuple:
        """
        Need to set RGB values when using RGB only, call this function directly return HEX string.
        Belike:
        print(RGB(16, 16, 16).of())
        Output:
        #101010
        

        需要在只用 RGB 时设置 RGB 值，调用此函数直接放回 HEX 字符串
        比如：
        print(RGB(16, 16, 16).of())
        输出：
        #101010
        """    
        ...
    def ofnum(r : int, g : int, b : int) -> 'RGB':
        """
        Enter RGB values and return the HEX string.


        输入 RGB 值，返回 HEX 字符串。
        """
        ...
    def ofhex(hex_str : str) -> RGB:
        """
        Convert HEX to RGB values and return the result.


        将 HEX 转化成 RGB 值并返回
        """
        ...