# Camera
camera_position : dict = {"x": 0, "y" : 0}
camera_size : float = 1.0
camera_d : int = 0 # 0 = up, 90 = right, 180 = down, 270 = left
screen_center : dict = {"x" : 0, "y" : 0}
minimum : float = 0.00000000000001


# Animation Engine Data
ae_images_position_x : dict = {}
ae_images_position_y : dict = {}
ae_images_path : dict = {}
ae_images_direction : dict = {}
ae_images_size_x : dict = {}
ae_images_size_y : dict = {}
ae_next_id : int = 0 # 下一个可用的ID
ae_images_id : dict = {} # 图片ID与图片路径的映射
ae_images_type : dict = {}

ae_every_frame_position_x : dict = {}
ae_every_frame_position_y : dict = {}
ae_every_frame_path : dict = {}
ae_every_frame_direction : dict = {}
ae_every_frame_size_x : dict = {}
ae_every_frame_size_y : dict = {}
ae_every_frame_type : dict = {}