"""
Animation Library
A simple 2D frame animation tool that supports loading images, automatic playback, and displaying animations, camera control, and an online real-time skeleton frame animation editor.
And if you need help in the editor, use the animation_help() function to get assistance. Go ahead and try it out!


Exceptions:
    NotFoundFileError  - Raised when the file does not exist
    UnboundWindowError - Raised when the window is not bound
    ImageNotShowError  - Raised when the image is not displayed
    NotFoundAliasError - Raised when the alias does not exist
    ValueError         - Raised when the input data is inconsistent with the facts


Animation 动画库
简易 2D 帧动画工具，支持加载图片、自动播放、显示动画、摄像机控制、在线实时骨骼帧动画编辑器
以及拥有在编辑器中寻求帮助，使用 animation_help() 函数去寻求帮助，快去试试吧！


异常：
    NotFoundFileError  - 文件不存在时抛出
    UnboundWindowError - 窗口未绑定时抛出
    ImageNotShowError  - 图像未显示时抛出
    NotFoundAliasError - 别名不存在时抛出
    ValueError         - 填写的数据不符合事实时抛出
"""

from .Animation import (
    animation_help, 
    is_image_showing, 
    is_animation_started, 
    get_animation_frame, 
    add_file_path, 
    image_show, 
    animation_start, 
    animation_stop, 
    set_animation_frame, 
    set_animation_speed, 
    animation_reverse, 
    animation_reverse_back, 
    AnimationStatus
)
from .animation_sprite import AnimationSprite
from .text import *
from .rgb import RGB
from .camera import Camera

__version__ = "1.5.0"
__author__ = "WatermelonCode"
__email__ = "watermeloncode@foxmail.com"
__license__ = "MIT"
__author_from__ = "China"

__all__ = [
    'animation_help',
    'is_image_showing',
    'is_animation_started',
    'get_animation_frame',
    'add_file_path',
    'image_show',
    'animation_start',
    'animation_stop',
    'set_animation_frame',
    'set_animation_speed',
    'animation_reverse',
    'animation_reverse_back',
    'AnimationSprite',
    'AnimationStatus',
    'RGB',
    'Camera'
]